Weather regimes
===============

s2dverification contains a set of functions to compute weather regime classifications. The goal fo this analysis is to generate a set of patterns able to characterize the different circulation structures occurring each month/season. 

In case you want to investigate the s2dverification functionalities you can:

- Load s2dverification with the following command:

```r
library(s2dverification)
```

- The documentation of s2dverification is available online here:

https://cran.r-project.org/web/packages/s2dverification/s2dverification.pdf

Seasonal forecasts of weather regimes
-----------------------------------

### 1- Load files
- The selected circulation variable is sea level pressure (psl), however other variables such as geopotential at 500 hPa can be also used.
- To illustrate the weather regime analysis we have employed the traditional Euro-Atlantic domain [85.5ºW-45ºE; 27-81ºN]]
- The sesonal predictions employed are those from ECMWF System 4 (Molteni et al. 2011) and as a reference dataset we have used the ERA-Interim reanalysis (Dee et al. 2011). 

```r
sdates <- paste0(1990:2010, '1201')
data <- Load('psl', exp = 'system4_m1',
             obs = 'erainterim',
             sdates = sdates,
             storefreq='daily',
             leadtimemin = 1, leadtimemax = 31,
             latmin = 27, latmax = 81,
             lonmin = 274.5, lonmax = 45,output = 'lonlat')
```

### 2- Daily anomalies based on a smoothed climatology
Weather regimes are based on daily anomalies. These anomalies have been computed as deviations from the daily climatologies which have been filtered by a LOESS filter (Cleveland and Delvin, 1988) to remove the short-term variability and retain the annual cycle (Mahlstein et al. 2015). This filter can be helpful to better isolate quasi stationary periods (Hannachi et al. 2017)

```r
clim<-Clim(var_exp = data$mod,var_obs = data$obs,memb=F)
Loess<-function(clim,loess_span){
  data<-data.frame(ensmean=clim,day=1:length(clim))
  loess_filt<-loess(ensmean~day,data,span=loess_span)
  output<-predict(loess_filt)
  return(output)
}
clim_smoothed_obs<-aperm(apply(clim$clim_obs,c(1:length(dim(clim$clim_obs)))[-which(names(dim(clim$clim_obs))=='ftime')],Loess,loess_span=1),c(2,1,3,4))
clim_smoothed_exp<-aperm(apply(clim$clim_exp,c(1:length(dim(clim$clim_exp)))[-which(names(dim(clim$clim_exp))=='ftime')],Loess,loess_span=1),c(2,1,3,4))

anom_obs<-Ano(data$obs,clim_smoothed_exp)
anom_exp<-Ano(data$mod,clim_smoothed_exp)

```
### 3- Weather regimes in observations 
One of the most common methods used in climate research for the classification of weather regimes is the k-means algorithm (Michelangeli et al. 1995, Strauss et al 2007). This clustering method produces a partition of all states in a predefined number of clusters (ncenters), which maximizes the ratio of variance among the clusters centroids and the intra-cluster variance. 
The cluster partitions are obtained from an iterative process in which the centroid coordinates selected are those that produces the maximum variance ratio. In this analysis the cluster partitions have been generated from 100 iterations with 30 different initial centroids (by default, nstart = 30, iter.max = 100)

```r
WR_obs<-WeatherRegime(data=anom_obs,EOFS=FALSE,lat_weights = TRUE,lat=lats,ncenters = 4)
```

### 4- Visualisation of the observed weather regimes

 ```r
titles<-paste0('freq = ',round(WR$frequency,1),'%')
PlotLayout(PlotEquiMap,c(1,2),lon=data$lon,lat=data$lat,var=WR$composite/100,
           titles=sapply('freq = ',paste0,paste0(round(WR$frequency,1),'%')),filled.continents=F,
           axelab=F,draw_separators = T,subsampleg = 1,brks=seq(-16,16,by=2),
           bar_extra_labels = c(2,0,0,0))
```
### 5- Weather regimes in the predictions

The predicted weather regimes are obtained by the matching of the predicted anomalies for each particular day,month,member and lead time with the observed clusters (obtained in step 3). The map of anomalies will be assigned to the predefined cluster for which the Eucledian distance is minimized. This method guarantees that the predicted weather regimes have very similar spatial structures to the observed predictions, which is essential for the verification of the predicted weather regimes. 

 ```r
reference<-drop(WR$composite)
names(dim(reference))<-c('lat','lon','nclust')
WR_exp<-RegimesAssign(var_ano=anom_exp,ref_maps=reference,lats=lats)
```
### 6- Visualisation of the predicted weather regimes
```
PlotLayout(PlotEquiMap,c(1,2),lon=data$lon,lat=data$lat,var=WR_exp$composite/100,
           titles=sapply('freq = ',paste0,paste0(round(WR_exp$frequency,1),'%')),
           filled.continents=F,
           axelab=F,draw_separators = T,subsampleg = 1,brks=seq(-16,16,by=2),
           bar_extra_labels = c(2,0,0,0))
```